package com.ynet.life.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.InvalidArgumentException;
import com.ynet.gene.data.ObjectNotFoundException;
import com.ynet.life.sujrb.util.SignUtils;
import com.ynet.life.util.PropertiesFile;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import java.util.Properties;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.entity.ContentType;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.DefaultHttpClient;
import org.apache.http.util.EntityUtils;
import org.json.JSONObject;

/* loaded from: com_ynet_life_action.jar:com/ynet/life/action/SyncDataToGZRPlatform.class */
public class SyncDataToGZRPlatform extends LifeJDBCAction {
    private String inputFields;
    private String outputFields;
    private String type;
    private String SECRET = "";
    private String BASE_URL = "";
    private String APP_KEY = "";

    public String getInputFields() {
        return this.inputFields;
    }

    public void setInputFields(String inputFields) {
        this.inputFields = inputFields;
    }

    public String getOutputFields() {
        return this.outputFields;
    }

    public void setOutputFields(String outputFields) {
        this.outputFields = outputFields;
    }

    public String getType() {
        return this.type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String execute(Context ctx) {
        try {
            try {
                Properties bankDBSourceProperties = PropertiesFile.getProperties("/properties/gzrData.properties");
                this.SECRET = bankDBSourceProperties.getProperty("SECRET");
                this.BASE_URL = bankDBSourceProperties.getProperty("BASE_URL");
                this.APP_KEY = bankDBSourceProperties.getProperty("APP_KEY");
                System.out.println("开始传输=================");
                Map<String, String> requestMap = new HashMap<>();
                Map<String, Object> postParameters = new HashMap<>();
                String timestamp = String.valueOf(System.currentTimeMillis());
                requestMap.put("app_key", this.APP_KEY);
                requestMap.put("format", "json");
                requestMap.put("sign_method", "md5");
                requestMap.put("timestamp", timestamp);
                requestMap.put("v", "1.0");
                postParameters.put("app_key", this.APP_KEY);
                postParameters.put("format", "json");
                postParameters.put("sign_method", "md5");
                postParameters.put("timestamp", timestamp);
                postParameters.put("v", "1.0");
                if ("1".equals(this.type)) {
                    System.out.println("开始授信=================");
                    creditData(ctx, requestMap, postParameters);
                } else if ("2".equals(this.type)) {
                    System.out.println("开始放款=================");
                    loanData(ctx, requestMap, postParameters);
                } else if ("3".equals(this.type)) {
                    System.out.println("开始还款=================");
                    repayData(ctx, requestMap, postParameters);
                }
                String sign = SignUtils.signTopRequest(requestMap, this.SECRET);
                postParameters.put("sign", sign);
                System.out.println("请求地址=================" + this.BASE_URL);
                System.out.println("发送请求==============");
                String string = MapUrlParamsUtils.getUrlParamsByMap(postParameters);
                System.out.println("参数1=========".concat(String.valueOf(string)));
                HttpPost httpPost = new HttpPost(this.BASE_URL);
                DefaultHttpClient httpClient = new DefaultHttpClient();
                StringEntity se = new StringEntity(string, "utf-8");
                se.setContentType(ContentType.APPLICATION_FORM_URLENCODED.toString());
                httpPost.setEntity(se);
                String message = EntityUtils.toString(httpClient.execute(httpPost).getEntity(), "utf-8");
                System.out.println("=======返回信息：".concat(String.valueOf(message)));
                JSONObject data = new JSONObject(message);
                ctx.put("serName", this.BASE_URL);
                ctx.put("accesstoken", string);
                ctx.put("serResult", data.toString());
                System.out.println("请求返回==============");
                if ("1".equals(data.getString("code"))) {
                    System.out.println("请求成功==============");
                    if ("2".equals(this.type)) {
                        String postId = data.getString("postId");
                        ctx.setDataValue("data3", postId);
                    }
                    ctx.setDataValue("data2", data.getString("message"));
                } else {
                    ctx.setDataValue("data2", data.getString("errMsg"));
                }
                ctx.setDataValue("data1", data.getString("code"));
                System.out.println("结束传输=================");
                return "0";
            } catch (GENEException e) {
                System.out.println("错误================");
                ctx.setDataValue("data1", "ESBN000001");
                ctx.setDataValue("data2", e.getMessage());
                e.printStackTrace();
                return "0";
            }
        } catch (Throwable unused) {
            return "0";
        }
    }

    private void repayData(Context ctx, Map<String, String> requestMap, Map<String, Object> postParameters) throws ObjectNotFoundException, InvalidArgumentException {
        requestMap.put("method", "api.zhengxin.customs.repay.apply");
        requestMap.put("reqNo", (String) ctx.getDataValue("GZReqNo"));
        requestMap.put("postId", (String) ctx.getDataValue("postId"));
        requestMap.put("repayTime", (String) ctx.getDataValue("rlDate"));
        requestMap.put("repayAmount", (String) ctx.getDataValue("rlAmt"));
        requestMap.put("principal", (String) ctx.getDataValue("principal"));
        requestMap.put("interest", (String) ctx.getDataValue("Interest"));
        requestMap.put("loanBalance", (String) ctx.getDataValue("loanBalance"));
        requestMap.put("isOverdue", (String) ctx.getDataValue("isOverdue"));
        requestMap.put("contractNumber", (String) ctx.getDataValue("loaReceiptNo"));
        requestMap.put("loanNumber", (String) ctx.getDataValue("loanNum"));
        requestMap.put("fiveCategory", (String) ctx.getDataValue("fiveCategoryRepay"));
        postParameters.put("method", "api.zhengxin.customs.repay.apply");
        postParameters.put("reqNo", (String) ctx.getDataValue("GZReqNo"));
        postParameters.put("postId", (String) ctx.getDataValue("postId"));
        postParameters.put("repayTime", (String) ctx.getDataValue("rlDate"));
        postParameters.put("repayAmount", (String) ctx.getDataValue("rlAmt"));
        postParameters.put("principal", (String) ctx.getDataValue("principal"));
        postParameters.put("interest", (String) ctx.getDataValue("Interest"));
        postParameters.put("loanBalance", (String) ctx.getDataValue("loanBalance"));
        postParameters.put("isOverdue", (String) ctx.getDataValue("isOverdue"));
        postParameters.put("contractNumber", (String) ctx.getDataValue("loaReceiptNo"));
        postParameters.put("loanNumber", (String) ctx.getDataValue("loanNum"));
        postParameters.put("fiveCategory", (String) ctx.getDataValue("fiveCategoryRepay"));
    }

    private void loanData(Context ctx, Map<String, String> requestMap, Map<String, Object> postParameters) throws GENEException {
        String state = (String) ctx.getDataValue("state");
        requestMap.put("method", "api.zhengxin.customs.post.apply");
        postParameters.put("method", "api.zhengxin.customs.post.apply");
        if ("305".equals(state)) {
            requestMap.put("reqNo", (String) ctx.getDataValue("GZReqNo"));
            requestMap.put("state", (String) ctx.getDataValue("state"));
            postParameters.put("reqNo", (String) ctx.getDataValue("GZReqNo"));
            postParameters.put("state", (String) ctx.getDataValue("state"));
            return;
        }
        requestMap.put("reqNo", (String) ctx.getDataValue("GZReqNo"));
        requestMap.put("state", (String) ctx.getDataValue("state"));
        requestMap.put("approvePostAmount", (String) ctx.getDataValue("amt"));
        requestMap.put("approvePostStartDate", (String) ctx.getDataValue("startdate"));
        requestMap.put("approvePostEndDate", (String) ctx.getDataValue("enddate"));
        requestMap.put("postPeriod", (String) ctx.getDataValue("limitDate"));
        requestMap.put("rate", (String) ctx.getDataValue("startRate"));
        requestMap.put("creditContractNum", (String) ctx.getDataValue("loaFlaFlowNo"));
        requestMap.put("loanNum", (String) ctx.getDataValue("loanNum"));
        requestMap.put("guaranteeType", (String) ctx.getDataValue("guaType"));
        requestMap.put("fiveCategory", (String) ctx.getDataValue("fiveCategory"));
        postParameters.put("reqNo", (String) ctx.getDataValue("GZReqNo"));
        postParameters.put("state", (String) ctx.getDataValue("state"));
        postParameters.put("approvePostAmount", (String) ctx.getDataValue("amt"));
        postParameters.put("approvePostStartDate", (String) ctx.getDataValue("startdate"));
        postParameters.put("approvePostEndDate", (String) ctx.getDataValue("enddate"));
        postParameters.put("postPeriod", (String) ctx.getDataValue("limitDate"));
        postParameters.put("rate", (String) ctx.getDataValue("startRate"));
        postParameters.put("creditContractNum", (String) ctx.getDataValue("loaFlaFlowNo"));
        postParameters.put("loanNum", (String) ctx.getDataValue("loanNum"));
        postParameters.put("guaranteeType", (String) ctx.getDataValue("guaType"));
        postParameters.put("fiveCategory", (String) ctx.getDataValue("fiveCategory"));
    }

    private void creditData(Context ctx, Map<String, String> requestMap, Map<String, Object> postParameters) throws GENEException {
        String startDate = (String) ctx.getDataValue("centreCreditDate");
        String centreCreditTimeLimit = (String) ctx.getDataValue("centreCreditTimeLimit");
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        new Date();
        Calendar calendar = Calendar.getInstance();
        try {
            Date date1 = sdf.parse(startDate);
            calendar.setTime(date1);
        } catch (ParseException e) {
            System.out.println("授信错误" + e.getMessage());
            e.printStackTrace();
        }
        String endDate = "";
        if (centreCreditTimeLimit != null && !"".equals(centreCreditTimeLimit)) {
            calendar.add(2, Integer.valueOf(centreCreditTimeLimit).intValue());
            endDate = sdf.format(calendar.getTime());
        }
        String str = (String) ctx.getDataValue("centreCreditAmount");
        String centerAmount = str;
        if (str == null || "".equals(centerAmount)) {
            centerAmount = "0";
        }
        requestMap.put("method", "api.zhengxin.customs.credit.apply");
        requestMap.put("reqNo", (String) ctx.getDataValue("GZReqNo"));
        requestMap.put("state", (String) ctx.getDataValue("centreApprovalResult"));
        requestMap.put("centerAmount", String.valueOf(Double.valueOf(centerAmount).doubleValue() / 10000.0d));
        requestMap.put("centerStartDate", (String) ctx.getDataValue("centreCreditDate"));
        requestMap.put("centerEndDate", endDate);
        requestMap.put("reason", (String) ctx.getDataValue("noPassReason"));
        postParameters.put("method", "api.zhengxin.customs.credit.apply");
        postParameters.put("reqNo", (String) ctx.getDataValue("GZReqNo"));
        postParameters.put("state", (String) ctx.getDataValue("centreApprovalResult"));
        postParameters.put("centerAmount", String.valueOf(Double.valueOf(centerAmount).doubleValue() / 10000.0d));
        postParameters.put("centerStartDate", (String) ctx.getDataValue("centreCreditDate"));
        postParameters.put("centerEndDate", endDate);
        postParameters.put("reason", (String) ctx.getDataValue("noPassReason"));
    }
}
